package com.arkivanov.sample.shared.multipane.database

import kotlin.random.Random

internal object LorenIpsumGenerator {

    fun generate(count: Int, minWordLength: Int = 1): List<String> =
        List(count) {
            var word: String
            do {
                word = words.random()
            } while (word.length < minWordLength)
            word
        }

    fun generateSentence(): String =
        generate(count = Random.nextInt(1, 15))
            .joinToString(
                separator = " ",
                prefix = words.random().replaceFirstChar(Char::uppercase),
                postfix = "."
            )

    private val words =
        listOf(
            "a",
            "ab",
            "abducat",
            "abest",
            "abhorreant",
            "ac",
            "accedere",
            "accedis",
            "accedit",
            "accedunt",
            "accessio",
            "accommodare",
            "accurate",
            "accuratius",
            "accusamus",
            "accusantibus",
            "accusantium",
            "accusata",
            "accusator",
            "acri",
            "acute",
            "acuti",
            "acutum",
            "acutus",
            "ad",
            "adamare",
            "addidisti",
            "adduci",
            "adest",
            "adhaesiones",
            "adhibenda",
            "adhibuit",
            "adhuc",
            "adiit",
            "adipiscendarum",
            "adipisci",
            "adipiscuntur",
            "adiungimus",
            "adiuvet",
            "administrari",
            "admirer",
            "admissum",
            "admodum",
            "admonere",
            "admonitionem",
            "adolescens",
            "adoptionem",
            "adquiescere",
            "adversa",
            "adversantur",
            "adversarium",
            "aegritudine",
            "aegritudinem",
            "aegritudines",
            "aegritudo",
            "aeque",
            "aequi",
            "aequitate",
            "aequitatem",
            "aequo",
            "aequum",
            "aetatis",
            "aeterno",
            "aeternum",
            "affecta",
            "affecti",
            "affectus",
            "afferat",
            "afferre",
            "afferrent",
            "affert",
            "afficit",
            "afficitur",
            "affirmatis",
            "afflueret",
            "afranius",
            "agam",
            "agatur",
            "aiebat",
            "ait",
            "aiunt",
            "albam",
            "albuci",
            "albucius",
            "alia",
            "aliae",
            "aliam",
            "alias",
            "aliena",
            "alienae",
            "alienum",
            "alienus",
            "alii",
            "alios",
            "aliqua",
            "aliquam",
            "aliquando",
            "aliquem",
            "aliquid",
            "aliquo",
            "aliquod",
            "aliquos",
            "aliter",
            "aliud",
            "allevatio",
            "alliciat",
            "allicit",
            "altera",
            "alteram",
            "alterum",
            "amaret",
            "amarissimam",
            "amatoriis",
            "ambigua",
            "amentur",
            "amet",
            "amice",
            "amici",
            "amicis",
            "amicitia",
            "amicitiae",
            "amicitiam",
            "amicitias",
            "amicorum",
            "amicos",
            "amicum",
            "amorem",
            "amori",
            "amoris",
            "amotio",
            "amplificarique",
            "amputata",
            "an",
            "ancillae",
            "andriam",
            "angatur",
            "angere",
            "angore",
            "angoribus",
            "angusta",
            "angusti",
            "animadversionem",
            "animadversionis",
            "animadvertat",
            "animal",
            "animi",
            "animis",
            "animo",
            "animos",
            "animum",
            "animumque",
            "animus",
            "ante",
            "anteponant",
            "antiopam",
            "antipatrum",
            "antiqua",
            "antiquis",
            "antiquitate",
            "apeirian",
            "aperiam",
            "aperiri",
            "aperta",
            "apertam",
            "appareat",
            "appellant",
            "appellantur",
            "appellat",
            "appetendi",
            "appetendum",
            "appetere",
            "approbantibus",
            "apte",
            "aptior",
            "aptissimum",
            "aptius",
            "apud",
            "arare",
            "arbitramur",
            "arbitrantur",
            "arbitrarer",
            "arbitraretur",
            "arbitratu",
            "arbitrer",
            "arbitrium",
            "arbitror",
            "architecto",
            "ardore",
            "arguerent",
            "argumentandum",
            "argumentum",
            "aristippi",
            "aristippus",
            "aristotele",
            "aristotelem",
            "aristoteli",
            "armatum",
            "arridens",
            "ars",
            "arte",
            "artem",
            "artes",
            "artibus",
            "artifex",
            "artis",
            "asperiores",
            "aspernandum",
            "aspernari",
            "aspernatur",
            "asperner",
            "asperum",
            "assecutus",
            "assentiar",
            "assentior",
            "assidua",
            "assiduitas",
            "assueverit",
            "assumenda",
            "astris",
            "at",
            "athenis",
            "atilii",
            "atomi",
            "atomis",
            "atomorum",
            "atomos",
            "atomum",
            "atomus",
            "atque",
            "atqui",
            "attento",
            "attico",
            "attingere",
            "attulit",
            "auctori",
            "audaces",
            "audeam",
            "audiam",
            "audiebam",
            "audiebamus",
            "audire",
            "audita",
            "audivi",
            "augendas",
            "augeri",
            "aut",
            "autem",
            "avocent",
            "beata",
            "beatae",
            "beatam",
            "beate",
            "beateque",
            "beatus",
            "bella",
            "bello",
            "bene",
            "benivole",
            "benivolentiam",
            "bestiae",
            "blanditiis",
            "bona",
            "bonae",
            "bonarum",
            "bonas",
            "bonis",
            "bono",
            "bonorum",
            "bonum",
            "brevi",
            "brevis",
            "breviter",
            "brute",
            "brutus",
            "c",
            "cadere",
            "caecilii",
            "caeco",
            "caelo",
            "calere",
            "campum",
            "canes",
            "captet",
            "capti",
            "captiosa",
            "careat",
            "carere",
            "careret",
            "caret",
            "caritatem",
            "carum",
            "causa",
            "causae",
            "causam",
            "causas",
            "cedentem",
            "celeritas",
            "censes",
            "censet",
            "centurionum",
            "cepisse",
            "ceramico",
            "cernantur",
            "cernimus",
            "certa",
            "certae",
            "certamen",
            "certe",
            "certissimam",
            "ceteris",
            "cetero",
            "ceterorum",
            "chaere",
            "choro",
            "chorusque",
            "chremes",
            "chrysippe",
            "chrysippi",
            "chrysippo",
            "cibo",
            "circumcisaque",
            "cives",
            "civibus",
            "civitas",
            "civitatis",
            "civium",
            "clamat",
            "clariora",
            "claris",
            "clarorum",
            "claudicare",
            "cn",
            "coercendi",
            "coerceri",
            "cogitarent",
            "cogitavisse",
            "cogitemus",
            "cognita",
            "cognitio",
            "cognitione",
            "cognitionem",
            "cognitionis",
            "cognitioque",
            "cognomen",
            "cognoscerem",
            "cognosci",
            "cohaerescant",
            "cohaerescent",
            "collaudata",
            "collegi",
            "collegisti",
            "comit",
            "commemorandis",
            "commenticiam",
            "commodi",
            "commodis",
            "commodius",
            "commune",
            "comparandae",
            "comparare",
            "comparat",
            "comparaverit",
            "complectitur",
            "complexiones",
            "compluribus",
            "compositis",
            "comprehenderit",
            "comprobavit",
            "concederetur",
            "concedo",
            "concertationesque",
            "concessum",
            "conciliant",
            "concludaturque",
            "conclusionemque",
            "conclusum",
            "concordia",
            "concupiscunt",
            "concursio",
            "concursionibus",
            "conducunt",
            "conectitur",
            "conetur",
            "confectum",
            "conferebamus",
            "conficiuntque",
            "conficiuntur",
            "confidam",
            "confidere",
            "confidet",
            "confirmare",
            "confirmat",
            "confirmatur",
            "confirmavit",
            "conflixisse",
            "conformavit",
            "congressus",
            "coniuncta",
            "coniunctione",
            "conquirendae",
            "conquisitis",
            "conscientia",
            "conscientiam",
            "consectetur",
            "consecutionem",
            "consecutus",
            "consedit",
            "consentaneum",
            "consentientis",
            "consentinis",
            "consequamur",
            "consequantur",
            "consequatur",
            "consequentis",
            "consequentium",
            "consequi",
            "consequuntur",
            "consilia",
            "consiliisque",
            "consilio",
            "consistat",
            "consoletur",
            "conspectum",
            "conspiratione",
            "constantia",
            "constituam",
            "constituamus",
            "constituant",
            "constituit",
            "constituto",
            "constringendos",
            "consuetudine",
            "consuetudinum",
            "consuevit",
            "consul",
            "consulatu",
            "consule",
            "consumere",
            "consumeret",
            "contemnentes",
            "contemnere",
            "contemnit",
            "contenta",
            "contentam",
            "contentiones",
            "contentus",
            "contereret",
            "continens",
            "continent",
            "contineret",
            "contineri",
            "contra",
            "contrariis",
            "controversia",
            "contumeliae",
            "conturbamur",
            "convenire",
            "conveniunt",
            "conversa",
            "conversam",
            "convicia",
            "convincere",
            "copiosae",
            "copulatas",
            "copulationes",
            "copulationesque",
            "corpora",
            "corpore",
            "corporis",
            "corporisque",
            "corporum",
            "corpus",
            "correcta",
            "corrigere",
            "corrumpit",
            "corrupisti",
            "corrupte",
            "corrupti",
            "cotidie",
            "cotidieque",
            "credere",
            "credo",
            "cruciantur",
            "crudeli",
            "crudelis",
            "cui",
            "cuiquam",
            "cuius",
            "culpa",
            "cum",
            "cumanum",
            "cumque",
            "cupiditate",
            "cupiditates",
            "cupiditatibus",
            "cupiditatibusque",
            "cupiditatum",
            "cupio",
            "cur",
            "cura",
            "curiosi",
            "curis",
            "cursu",
            "cyrenaicisque",
            "cyrenaicos",
            "d",
            "damna",
            "dare",
            "data",
            "de",
            "debemus",
            "debent",
            "debeo",
            "debet",
            "debilitatem",
            "debilitati",
            "debitis",
            "declarant",
            "declinabunt",
            "declinare",
            "declinatio",
            "declinationem",
            "decore",
            "dedecora",
            "dediti",
            "deditum",
            "dedocendi",
            "dedocere",
            "deduceret",
            "defatigatio",
            "defendere",
            "defendit",
            "defenditur",
            "defensa",
            "definitiones",
            "defuit",
            "defuturum",
            "degendae",
            "dein",
            "deinde",
            "delapsa",
            "delectamur",
            "delectant",
            "delectari",
            "delectat",
            "delectatio",
            "delectatum",
            "delectet",
            "delectu",
            "delectus",
            "deleniti",
            "delicata",
            "delicatissimi",
            "democritea",
            "democriti",
            "democrito",
            "democritum",
            "democritus",
            "denique",
            "deorsum",
            "deorsus",
            "deorum",
            "depravare",
            "depravata",
            "depravate",
            "depravatum",
            "depulsa",
            "derepta",
            "derigatur",
            "deserere",
            "deseruisse",
            "deserunt",
            "desiderabile",
            "desiderant",
            "desiderare",
            "desideraret",
            "desiderat",
            "desideraturam",
            "desiderent",
            "desideret",
            "desistemus",
            "desistunt",
            "desperantes",
            "despicationes",
            "deteriora",
            "deterius",
            "deterret",
            "deterritum",
            "deterruisset",
            "detracta",
            "detractio",
            "detractis",
            "detracto",
            "detraxisse",
            "detraxit",
            "detrimenti",
            "dialectica",
            "dicam",
            "dicant",
            "dicantur",
            "dicas",
            "dicat",
            "dicebas",
            "dicemus",
            "dicenda",
            "dicendum",
            "dicent",
            "dicere",
            "diceret",
            "diceretur",
            "dices",
            "dici",
            "dicit",
            "dicitis",
            "dicitur",
            "dicta",
            "dictas",
            "dictum",
            "dicturam",
            "dicturum",
            "dicunt",
            "didicerimus",
            "didicisse",
            "didicisset",
            "diesque",
            "difficile",
            "difficilem",
            "difficiles",
            "difficilius",
            "dignissimos",
            "dignitatis",
            "diis",
            "diligamus",
            "diligant",
            "diligenter",
            "diligi",
            "diogenem",
            "directam",
            "dirigentur",
            "discedere",
            "discenda",
            "discere",
            "discidia",
            "disciplina",
            "disciplinae",
            "disciplinam",
            "disciplinis",
            "discordans",
            "discordant",
            "discordia",
            "discordiae",
            "displicet",
            "disputando",
            "disputandum",
            "disputari",
            "disputata",
            "disputatione",
            "disputationi",
            "disputatum",
            "dissensio",
            "dissentias",
            "dissentientium",
            "dissentiet",
            "dissentio",
            "dissentiunt",
            "disserendi",
            "disserendum",
            "disseretur",
            "disseruerunt",
            "disserui",
            "disserunt",
            "dissidens",
            "dissident",
            "distinctio",
            "distinguantur",
            "distinguique",
            "distrahi",
            "diu",
            "diuturnitatem",
            "diuturnum",
            "divelli",
            "dividendo",
            "divina",
            "divinum",
            "divitiarum",
            "divitias",
            "dixeris",
            "dixerit",
            "dixi",
            "dixissem",
            "dixisset",
            "dixit",
            "doceat",
            "docendi",
            "docere",
            "docet",
            "docti",
            "doctiores",
            "doctissimos",
            "doctrina",
            "doctrinis",
            "doctus",
            "docui",
            "doleamus",
            "dolemus",
            "dolendum",
            "dolere",
            "dolor",
            "dolore",
            "dolorem",
            "doloremque",
            "dolores",
            "doloribus",
            "doloris",
            "dolorum",
            "domesticarum",
            "dominationis",
            "dominorum",
            "dominos",
            "domo",
            "domus",
            "dubio",
            "dubitat",
            "dubitemus",
            "dubium",
            "duce",
            "ducem",
            "ducimus",
            "dulce",
            "dum",
            "duo",
            "durissimis",
            "duxit",
            "e",
            "ea",
            "eadem",
            "eademque",
            "eae",
            "eam",
            "eamque",
            "eaque",
            "earum",
            "earumque",
            "eas",
            "easque",
            "ecce",
            "effecerit",
            "effectrices",
            "efficere",
            "efficerent",
            "efficeret",
            "efficeretur",
            "effici",
            "efficiantur",
            "efficiat",
            "efficiatur",
            "efficiendi",
            "efficit",
            "efficitur",
            "efflorescere",
            "effluere",
            "effugiendorum",
            "ego",
            "egregios",
            "ei",
            "eidola",
            "eisque",
            "eitam",
            "eius",
            "eiusdem",
            "elaborare",
            "elaboraret",
            "electis",
            "electram",
            "elegans",
            "elegantis",
            "eligendi",
            "eloquentiam",
            "emancipaverat",
            "emolumenti",
            "emolumento",
            "enim",
            "ennii",
            "ennius",
            "eo",
            "eodem",
            "eoque",
            "eorum",
            "eorumque",
            "eos",
            "eosdem",
            "eosque",
            "epicurei",
            "epicureis",
            "epicureum",
            "epicuri",
            "epicuro",
            "epicurum",
            "epicurus",
            "epularum",
            "equidem",
            "equos",
            "eram",
            "erant",
            "erat",
            "erga",
            "ergo",
            "erigimur",
            "eriguntur",
            "erimus",
            "eripuit",
            "erit",
            "ero",
            "errata",
            "errem",
            "error",
            "errore",
            "errorem",
            "erroribus",
            "eruditi",
            "eruditionem",
            "erudito",
            "eruditus",
            "erunt",
            "esse",
            "essent",
            "esset",
            "est",
            "et",
            "etenim",
            "etiam",
            "etiamsi",
            "etsi",
            "eum",
            "eumque",
            "euripidis",
            "eveniet",
            "eveniunt",
            "eventurum",
            "everti",
            "evertitur",
            "evertunt",
            "evolutio",
            "evolvendis",
            "ex",
            "exaudita",
            "excelsus",
            "excepturi",
            "excruciant",
            "exeamus",
            "exedunt",
            "exeduntur",
            "exercendi",
            "exercitationem",
            "exercitumque",
            "exercitus",
            "exhorrescere",
            "exiguam",
            "eximiae",
            "existimant",
            "existimare",
            "existimavit",
            "existimo",
            "existunt",
            "exitum",
            "exorsus",
            "expectamus",
            "expectant",
            "expectat",
            "expectata",
            "expedire",
            "expedita",
            "expediunt",
            "expetenda",
            "expetendam",
            "expetendas",
            "expetendis",
            "expetendum",
            "expeteremus",
            "expeteretur",
            "expetitur",
            "expleantur",
            "explentur",
            "explicabo",
            "explicari",
            "explicatam",
            "explicatis",
            "explicavi",
            "expressas",
            "exquirere",
            "exquisitaque",
            "exquisitis",
            "extremo",
            "extremum",
            "exultat",
            "fabellas",
            "fabulae",
            "fabulas",
            "fabulis",
            "facere",
            "facerem",
            "facete",
            "faciam",
            "faciant",
            "faciendi",
            "faciendum",
            "faciendumve",
            "facile",
            "facilis",
            "facilius",
            "facillime",
            "facillimis",
            "facimus",
            "facio",
            "faciunt",
            "facta",
            "factis",
            "factorum",
            "facultas",
            "fallare",
            "falli",
            "falsarum",
            "falsi",
            "falsis",
            "falso",
            "fama",
            "fames",
            "familiarem",
            "familiari",
            "familiaritatem",
            "familias",
            "fana",
            "fastidii",
            "fastidium",
            "fatemur",
            "fatendum",
            "fautrices",
            "fecerint",
            "fecerit",
            "feci",
            "fecisse",
            "fecit",
            "ferae",
            "feramus",
            "ferant",
            "ferantur",
            "fere",
            "ferentur",
            "ferre",
            "ferrentur",
            "ferreum",
            "ferri",
            "ficta",
            "fictae",
            "fidelissimae",
            "fidem",
            "fieri",
            "filio",
            "filium",
            "fingi",
            "fingitur",
            "finibus",
            "finiri",
            "finis",
            "finitas",
            "finitum",
            "finxerat",
            "firmam",
            "firme",
            "firmissima",
            "firmissimum",
            "firmitatem",
            "fit",
            "flagitem",
            "fodere",
            "foedus",
            "fonte",
            "fore",
            "forensibus",
            "foris",
            "formidines",
            "formidinum",
            "fortasse",
            "forte",
            "fortibus",
            "fortitudinem",
            "fortitudinis",
            "fortitudo",
            "fortunae",
            "fortunam",
            "frequenter",
            "fructu",
            "fructuosam",
            "fruenda",
            "fruentem",
            "frui",
            "fruitur",
            "frustra",
            "fruuntur",
            "fuerit",
            "fuga",
            "fugiamus",
            "fugiat",
            "fugienda",
            "fugiendam",
            "fugiendis",
            "fugiendum",
            "fugiendus",
            "fugit",
            "fuisse",
            "fuissent",
            "fuisset",
            "fuit",
            "fungimur",
            "futura",
            "futuris",
            "futuros",
            "futurove",
            "gaudeat",
            "gaudemus",
            "gaudere",
            "generibusque",
            "generis",
            "genuit",
            "genus",
            "geometria",
            "geometriaque",
            "geometrica",
            "gerendarum",
            "gessisse",
            "gloriae",
            "gloriatur",
            "gloriosis",
            "graeca",
            "graecam",
            "graece",
            "graeci",
            "graecis",
            "graeco",
            "graecos",
            "graecum",
            "grata",
            "grate",
            "gratia",
            "gratiam",
            "gratissimo",
            "gravioribus",
            "gravis",
            "gravissimas",
            "gravissimis",
            "gravissimo",
            "gravitate",
            "graviter",
            "graviterque",
            "greges",
            "gubernatoris",
            "gustare",
            "gymnasia",
            "habeat",
            "habeatur",
            "habemus",
            "habendus",
            "habent",
            "habeo",
            "habere",
            "habet",
            "habuit",
            "hac",
            "hae",
            "haec",
            "haeret",
            "hanc",
            "harum",
            "has",
            "hausta",
            "hic",
            "hinc",
            "his",
            "historiae",
            "hoc",
            "homero",
            "homine",
            "hominem",
            "homines",
            "homini",
            "hominibus",
            "hominum",
            "homo",
            "honesta",
            "honestatis",
            "honeste",
            "honesto",
            "honestum",
            "honoris",
            "horreat",
            "horrent",
            "horribiles",
            "horrida",
            "hortatore",
            "hortensio",
            "horum",
            "hostem",
            "hosti",
            "hostis",
            "huc",
            "huic",
            "huius",
            "humili",
            "hunc",
            "iactant",
            "iactare",
            "iam",
            "ibidem",
            "id",
            "idcirco",
            "idem",
            "idque",
            "igitur",
            "ignavi",
            "ignavia",
            "ignaviamque",
            "ignem",
            "ignorant",
            "ignorare",
            "ignoratione",
            "ignota",
            "ii",
            "iis",
            "iisque",
            "illa",
            "illaberetur",
            "illae",
            "illam",
            "illas",
            "ille",
            "illi",
            "illis",
            "illius",
            "illo",
            "illud",
            "illum",
            "illustribus",
            "illustriora",
            "imagines",
            "imbutus",
            "imitarentur",
            "impediente",
            "impediri",
            "impedit",
            "impeditur",
            "impendere",
            "impendet",
            "impensa",
            "imperii",
            "imperiis",
            "imperio",
            "imperitorum",
            "imperitos",
            "impetu",
            "impetum",
            "impetus",
            "importari",
            "improbe",
            "improbis",
            "improborum",
            "in",
            "inane",
            "inanes",
            "inani",
            "inanitate",
            "inanium",
            "inbecilloque",
            "incidant",
            "inciderint",
            "inciderit",
            "incidunt",
            "inclusae",
            "incommoda",
            "incorrupte",
            "incorruptis",
            "inculta",
            "incurreret",
            "incurrunt",
            "incursione",
            "indicaverunt",
            "indignae",
            "indignius",
            "individua",
            "indocti",
            "indoctis",
            "indoctum",
            "inducitur",
            "industria",
            "industriae",
            "inermis",
            "inertissimae",
            "ineruditus",
            "inesse",
            "infantes",
            "infanti",
            "inferiorem",
            "infimum",
            "infinitio",
            "infinitis",
            "infinito",
            "infinitum",
            "inflammat",
            "inflammati",
            "ingenia",
            "ingenii",
            "ingeniis",
            "inhaererent",
            "inhumanus",
            "inimicus",
            "initia",
            "initiis",
            "iniucundus",
            "iniuria",
            "iniurias",
            "iniuste",
            "inliberali",
            "inmensae",
            "inmortalibus",
            "innumerabiles",
            "inopem",
            "inpendente",
            "inportuno",
            "inpotenti",
            "inprobis",
            "inprobitas",
            "inprobitatem",
            "inquam",
            "inquit",
            "insatiabiles",
            "inscientia",
            "insequitur",
            "insidiarum",
            "insipientiam",
            "insitam",
            "insolens",
            "instituendarum",
            "instituit",
            "institutionem",
            "instructior",
            "instructus",
            "integre",
            "integris",
            "intellegam",
            "intellegamus",
            "intellegaturque",
            "intellegebat",
            "intellegentium",
            "intellegere",
            "intellegerem",
            "intelleges",
            "intellegi",
            "intellegimus",
            "intellegitur",
            "intellegunt",
            "intemperantes",
            "intemperantiam",
            "inter",
            "intercapedo",
            "interdictum",
            "interea",
            "intereant",
            "interesse",
            "interesset",
            "interiret",
            "interpretaris",
            "interpretum",
            "interrogare",
            "interrogari",
            "intervalla",
            "intervenire",
            "intuemur",
            "intus",
            "inutile",
            "inveneris",
            "invenerit",
            "invenire",
            "inveniri",
            "inventore",
            "investigandi",
            "invidi",
            "invidia",
            "invidiae",
            "invidus",
            "invitat",
            "inviti",
            "involuta",
            "ipsa",
            "ipsam",
            "ipsarum",
            "ipsas",
            "ipse",
            "ipsi",
            "ipsis",
            "ipsius",
            "ipso",
            "ipsos",
            "ipsum",
            "iracundia",
            "iracundiae",
            "irridente",
            "is",
            "isdem",
            "ista",
            "istae",
            "istam",
            "iste",
            "isti",
            "istis",
            "istius",
            "ita",
            "itaque",
            "iuberet",
            "iucunda",
            "iucunde",
            "iucunditas",
            "iucunditate",
            "iucunditatem",
            "iucunditatis",
            "iucundius",
            "iucundo",
            "iucundum",
            "iudex",
            "iudicabit",
            "iudicandum",
            "iudicant",
            "iudicante",
            "iudicare",
            "iudicari",
            "iudicat",
            "iudicatum",
            "iudicem",
            "iudicia",
            "iudicio",
            "iudiciorumque",
            "iudicium",
            "iudico",
            "iure",
            "ius",
            "iuste",
            "iusteque",
            "iustioribus",
            "iustitia",
            "iustitiam",
            "iustius",
            "iusto",
            "iuvaret",
            "l",
            "labefactant",
            "labefactetur",
            "labitur",
            "labor",
            "laboramus",
            "laborat",
            "labore",
            "labores",
            "laboribus",
            "laboriosam",
            "laborum",
            "laetamur",
            "laetetur",
            "laetitia",
            "laetitiam",
            "late",
            "latina",
            "latinam",
            "latinas",
            "latine",
            "latinis",
            "laudabilis",
            "laudandis",
            "laudantium",
            "laudari",
            "laudatum",
            "laudatur",
            "laudem",
            "laus",
            "lectorem",
            "legam",
            "legant",
            "legantur",
            "legat",
            "legatis",
            "legemus",
            "legendam",
            "legendi",
            "legendis",
            "legendos",
            "legendum",
            "legendus",
            "legere",
            "legerint",
            "legimus",
            "legum",
            "leguntur",
            "leniat",
            "leniter",
            "levamur",
            "leviora",
            "levis",
            "levitatibus",
            "levius",
            "libenter",
            "liber",
            "liberabuntur",
            "liberae",
            "liberalitati",
            "liberamur",
            "liberatione",
            "liberavisse",
            "liberemus",
            "liberiusque",
            "libero",
            "liberos",
            "libidinem",
            "libidinibus",
            "libidinosarum",
            "libidinum",
            "libido",
            "libris",
            "libro",
            "licebit",
            "licet",
            "lictores",
            "lineam",
            "linguam",
            "liquidae",
            "litterae",
            "litteras",
            "litteris",
            "loca",
            "locatus",
            "locis",
            "loco",
            "locos",
            "locum",
            "locupletiorem",
            "locus",
            "logikh",
            "longinquitate",
            "loquerer",
            "loqueretur",
            "loqui",
            "loquuntur",
            "lucifugi",
            "lucilius",
            "ludicra",
            "ludus",
            "m",
            "macedonum",
            "maerores",
            "maestitiam",
            "magis",
            "magistra",
            "magna",
            "magnam",
            "magni",
            "magnis",
            "magnitudinem",
            "magnopere",
            "magnos",
            "magnosque",
            "magnum",
            "magnus",
            "maiestatis",
            "maior",
            "maiora",
            "maiorem",
            "maiores",
            "maioribus",
            "maiorum",
            "maius",
            "mala",
            "malarum",
            "male",
            "maledici",
            "maledicta",
            "malint",
            "malis",
            "malit",
            "malivoli",
            "malle",
            "malo",
            "malorum",
            "maluisset",
            "maluisti",
            "malum",
            "malunt",
            "mandamus",
            "mandaremus",
            "manilium",
            "manu",
            "manum",
            "manus",
            "materia",
            "maximam",
            "maximasque",
            "maxime",
            "maximeque",
            "maximi",
            "maximis",
            "maximisque",
            "maximo",
            "maximos",
            "me",
            "mea",
            "meam",
            "medeam",
            "medicorum",
            "mediocrem",
            "mediocris",
            "mediocritatem",
            "mediocriterne",
            "mediocrium",
            "medium",
            "mei",
            "meis",
            "mel",
            "meliore",
            "melius",
            "meminerimus",
            "meminerit",
            "meminerunt",
            "meminit",
            "memoria",
            "memoriter",
            "menandri",
            "menandro",
            "mens",
            "mente",
            "mentitum",
            "meo",
            "meque",
            "mererer",
            "metrodorus",
            "metu",
            "metuamus",
            "metum",
            "metuque",
            "metus",
            "mi",
            "migrare",
            "mihi",
            "militaris",
            "minima",
            "minime",
            "minimum",
            "minorem",
            "minuendas",
            "minuit",
            "minus",
            "minuti",
            "miraretur",
            "mirari",
            "miser",
            "miseram",
            "miserius",
            "miserum",
            "misisti",
            "mnesarchum",
            "moderatio",
            "moderatius",
            "modi",
            "modice",
            "modis",
            "modo",
            "modum",
            "modus",
            "molestia",
            "molestiae",
            "molestiam",
            "molestias",
            "molestum",
            "molita",
            "mollis",
            "mollitia",
            "momenti",
            "monet",
            "monstret",
            "monstruosi",
            "morati",
            "morbi",
            "morbis",
            "morborum",
            "morbos",
            "moribus",
            "mors",
            "morte",
            "mortem",
            "mortis",
            "motu",
            "motum",
            "motus",
            "moveat",
            "movere",
            "movet",
            "mox",
            "mucius",
            "multa",
            "multam",
            "multavit",
            "multi",
            "multis",
            "multitudinem",
            "multo",
            "multoque",
            "multos",
            "mundi",
            "mundus",
            "munere",
            "municipem",
            "muniti",
            "musicis",
            "mutae",
            "mutans",
            "mutat",
            "nacti",
            "nam",
            "nasci",
            "nascuntur",
            "nati",
            "natum",
            "natura",
            "naturae",
            "naturalem",
            "naturales",
            "naturam",
            "natus",
            "navigandi",
            "ne",
            "nec",
            "necessariae",
            "necessariam",
            "necessarius",
            "necesse",
            "necessitatibus",
            "negant",
            "negarent",
            "negat",
            "negent",
            "neglegentur",
            "neglegit",
            "neglexerit",
            "nemini",
            "nemo",
            "nemore",
            "neque",
            "nescio",
            "nesciunt",
            "nescius",
            "nihil",
            "nihilo",
            "nimis",
            "nimium",
            "nisi",
            "nivem",
            "nixam",
            "nobis",
            "nocet",
            "noctesque",
            "nollem",
            "nominant",
            "nominata",
            "nominavi",
            "nomine",
            "nomini",
            "nominis",
            "non",
            "nondum",
            "nonne",
            "noris",
            "nos",
            "nosmet",
            "nosque",
            "noster",
            "nostra",
            "nostram",
            "nostras",
            "nostri",
            "nostris",
            "nostro",
            "nostros",
            "nostrum",
            "notae",
            "notionem",
            "notissima",
            "novi",
            "novum",
            "nudus",
            "nulla",
            "nullae",
            "nullam",
            "nullas",
            "nulli",
            "nullo",
            "nullus",
            "num",
            "numen",
            "numeranda",
            "numeris",
            "numquam",
            "numquid",
            "numquidnam",
            "nunc",
            "nusquam",
            "nutu",
            "o",
            "ob",
            "obcaecati",
            "obiecta",
            "obligantur",
            "oblique",
            "oblivione",
            "obruamus",
            "occulta",
            "occultarum",
            "occulte",
            "occultum",
            "octavio",
            "oculis",
            "ocurreret",
            "oderis",
            "oderit",
            "odia",
            "odio",
            "odioque",
            "odit",
            "offendimur",
            "offendit",
            "officia",
            "officii",
            "officiis",
            "omittam",
            "omittantur",
            "omittendis",
            "omne",
            "omnem",
            "omnes",
            "omnesque",
            "omni",
            "omnia",
            "omnibus",
            "omnino",
            "omnis",
            "omnisque",
            "omnium",
            "opera",
            "operam",
            "operis",
            "operosam",
            "opes",
            "opibus",
            "opinemur",
            "opinionum",
            "opinor",
            "oporteat",
            "oportere",
            "oportet",
            "optabilem",
            "optari",
            "optime",
            "optimi",
            "optimum",
            "optimus",
            "optinere",
            "optio",
            "opus",
            "oratio",
            "oratione",
            "orationis",
            "oratoribus",
            "ordiamur",
            "ordinem",
            "orestem",
            "oriantur",
            "oritur",
            "ornamenta",
            "ornateque",
            "ornatum",
            "ornatus",
            "ortum",
            "ostendis",
            "ostendit",
            "otiosum",
            "p",
            "pacem",
            "pacto",
            "pacuvii",
            "paene",
            "panaetium",
            "parabilis",
            "paranda",
            "pararetur",
            "paratus",
            "parendum",
            "parentes",
            "paria",
            "pariant",
            "pariatur",
            "pariendarum",
            "pariter",
            "pariuntur",
            "pars",
            "parta",
            "parte",
            "partem",
            "partes",
            "partiendo",
            "partis",
            "partitio",
            "partus",
            "parum",
            "parvam",
            "parvos",
            "pater",
            "patet",
            "patiatur",
            "patientia",
            "patientiamque",
            "patre",
            "patria",
            "patriam",
            "patrioque",
            "patrius",
            "pauca",
            "paulo",
            "peccandi",
            "peccant",
            "pecuniae",
            "pecunias",
            "pedalis",
            "pellat",
            "pendet",
            "penitus",
            "per",
            "perciperet",
            "percipi",
            "percipiatur",
            "percipit",
            "percipitur",
            "percurri",
            "percussit",
            "perdiderunt",
            "perdiscere",
            "perfecto",
            "perferendis",
            "perfruique",
            "perfunctio",
            "pericula",
            "periculis",
            "periculum",
            "perinde",
            "permagna",
            "permanentes",
            "permulta",
            "perpauca",
            "perpaulum",
            "perpessio",
            "perpetiuntur",
            "perpetua",
            "perpetuam",
            "perpetuis",
            "persecuti",
            "persequeretur",
            "persequeris",
            "persius",
            "personae",
            "perspecta",
            "perspexit",
            "perspici",
            "perspiciatis",
            "perspicuum",
            "pertinaces",
            "pertinacia",
            "pertinax",
            "pertineant",
            "pertinerent",
            "perturbari",
            "perturbatur",
            "pervenias",
            "perveniri",
            "petat",
            "petentium",
            "petulantes",
            "phaedrum",
            "philosophari",
            "philosophi",
            "philosophia",
            "philosophiae",
            "philosophis",
            "philosopho",
            "philosophorum",
            "physici",
            "physicis",
            "physico",
            "placatae",
            "placeat",
            "placebit",
            "placet",
            "placuit",
            "plane",
            "plato",
            "platone",
            "platonem",
            "platonis",
            "plena",
            "pleniorem",
            "plerique",
            "plerisque",
            "plerumque",
            "plura",
            "pluribus",
            "plurimum",
            "plus",
            "plusque",
            "poena",
            "poenis",
            "poetae",
            "poetarum",
            "poetis",
            "politus",
            "polyaeno",
            "ponatur",
            "pondere",
            "ponderum",
            "ponendam",
            "ponit",
            "ponti",
            "ponunt",
            "populo",
            "porrecta",
            "porro",
            "posidonium",
            "posse",
            "possent",
            "posset",
            "possim",
            "possimus",
            "possint",
            "possit",
            "possum",
            "possumus",
            "possunt",
            "postea",
            "posteri",
            "postremo",
            "postulant",
            "postulet",
            "posuit",
            "poterimus",
            "poterit",
            "potest",
            "potiendi",
            "potione",
            "potiora",
            "potitur",
            "potius",
            "potuimus",
            "praebeat",
            "praeceptrice",
            "praeclara",
            "praeclaram",
            "praeclare",
            "praeclarorum",
            "praeda",
            "praesens",
            "praesenti",
            "praesentibus",
            "praesentium",
            "praesertim",
            "praesidia",
            "praesidium",
            "praestabiliorem",
            "praeter",
            "praeterea",
            "praetereat",
            "praeterierunt",
            "praeterita",
            "praeteritas",
            "praetermissum",
            "praetermittatur",
            "praetermittenda",
            "praetor",
            "praetore",
            "praetorem",
            "praetulerit",
            "prima",
            "primis",
            "primisque",
            "primo",
            "primorum",
            "primos",
            "primum",
            "primus",
            "principes",
            "principio",
            "privamur",
            "privatio",
            "privatione",
            "privavisse",
            "priventur",
            "pro",
            "probabis",
            "probabo",
            "probamus",
            "probant",
            "probantur",
            "probarem",
            "probarent",
            "probarentur",
            "probaretur",
            "probatum",
            "probaturum",
            "probatus",
            "probes",
            "probet",
            "probo",
            "procedat",
            "profecta",
            "profecto",
            "profectus",
            "proficiscuntur",
            "progrediens",
            "prohiberet",
            "prompta",
            "pronuntiaret",
            "propemodum",
            "proposita",
            "propositum",
            "propriae",
            "proprius",
            "propter",
            "propterea",
            "prorsus",
            "prosperum",
            "prospexit",
            "protervi",
            "provident",
            "provincia",
            "provincias",
            "provocarem",
            "provocatus",
            "publicam",
            "pueri",
            "puerilis",
            "pueriliter",
            "pueros",
            "pugnantibus",
            "pugnare",
            "pulcherrimum",
            "pulchraeque",
            "putamus",
            "putanda",
            "putant",
            "putarent",
            "putas",
            "putat",
            "putavisset",
            "putem",
            "putemus",
            "putent",
            "putet",
            "puto",
            "qua",
            "quadam",
            "quae",
            "quaedam",
            "quaeque",
            "quaerat",
            "quaerenda",
            "quaerendi",
            "quaerendum",
            "quaeri",
            "quaerimus",
            "quaeritur",
            "quaeso",
            "quaestionem",
            "quale",
            "quales",
            "qualisque",
            "quam",
            "quamquam",
            "quamque",
            "quamvis",
            "quandam",
            "quando",
            "quanta",
            "quantaque",
            "quanti",
            "quanto",
            "quantum",
            "quantumcumque",
            "quantus",
            "quapropter",
            "quarum",
            "quas",
            "quasi",
            "que",
            "quem",
            "queo",
            "qui",
            "quia",
            "quibus",
            "quibusdam",
            "quicquam",
            "quicquid",
            "quid",
            "quidam",
            "quiddam",
            "quidem",
            "quidque",
            "quietae",
            "quiete",
            "quietem",
            "quieti",
            "quietus",
            "quin",
            "quippe",
            "quippiam",
            "quis",
            "quisquam",
            "quisque",
            "quisquis",
            "quo",
            "quocirca",
            "quod",
            "quoddam",
            "quodsi",
            "quondam",
            "quoniam",
            "quoque",
            "quoquo",
            "quorum",
            "quos",
            "quosdam",
            "quosque",
            "quosvis",
            "quot",
            "ratio",
            "ratione",
            "rationem",
            "rationibus",
            "rationis",
            "re",
            "rebus",
            "recordamur",
            "recordatione",
            "recta",
            "rectas",
            "recte",
            "recteque",
            "recusabo",
            "recusandae",
            "reddidisti",
            "redeamus",
            "referatur",
            "referenda",
            "referri",
            "refert",
            "referta",
            "referuntur",
            "reformidans",
            "refugiendi",
            "regione",
            "regula",
            "reici",
            "reiciat",
            "reiciendis",
            "religionis",
            "relinqueret",
            "reliquaque",
            "reliquarum",
            "reliquerunt",
            "reliqui",
            "reliquisti",
            "rem",
            "remissius",
            "remotis",
            "renovata",
            "repellat",
            "repellendus",
            "repellere",
            "reperietur",
            "reperire",
            "reperiri",
            "reperiuntur",
            "repetitis",
            "reprehenderit",
            "reprehendunt",
            "reprehensa",
            "reprehensione",
            "reprehensiones",
            "reprimique",
            "repudiandae",
            "repugnantibus",
            "repugnantiumve",
            "reque",
            "requietis",
            "requirere",
            "rerum",
            "res",
            "respirare",
            "respondendum",
            "responsum",
            "restat",
            "restincto",
            "retinent",
            "retinere",
            "robustus",
            "rogatiuncula",
            "romano",
            "romanum",
            "ruant",
            "rudem",
            "ruinae",
            "rutilius",
            "sabinum",
            "saepe",
            "saepti",
            "sale",
            "salutandi",
            "salutatus",
            "saluti",
            "saluto",
            "sanciret",
            "sane",
            "sanguinem",
            "sanos",
            "saperet",
            "sapiens",
            "sapiente",
            "sapienter",
            "sapientes",
            "sapienti",
            "sapientia",
            "sapientiam",
            "sapientiamque",
            "sapientium",
            "satis",
            "satisfacit",
            "saxum",
            "scaevola",
            "scaevolam",
            "scientia",
            "scientiam",
            "scilicet",
            "scipio",
            "sciscat",
            "scribendi",
            "scribentur",
            "scribere",
            "scribi",
            "scribimus",
            "scripserit",
            "scripta",
            "scriptorem",
            "scriptum",
            "se",
            "secumque",
            "secunda",
            "secundum",
            "securi",
            "secutus",
            "sed",
            "sedatio",
            "sedentis",
            "seditione",
            "seditiones",
            "sedulitatem",
            "segniorem",
            "segnitiae",
            "seiunctum",
            "seiungi",
            "semel",
            "semper",
            "sempiternum",
            "senectutem",
            "senserit",
            "sensibus",
            "sensu",
            "sensum",
            "sensus",
            "sensuum",
            "sententia",
            "sententiae",
            "sententiam",
            "sentiamus",
            "sentiant",
            "sentio",
            "sentire",
            "sentiri",
            "sentit",
            "sentiunt",
            "sequamur",
            "sequatur",
            "seque",
            "sequi",
            "sequimur",
            "sequitur",
            "sermo",
            "sermone",
            "sero",
            "servare",
            "servata",
            "servire",
            "severa",
            "severitatem",
            "si",
            "sibi",
            "sic",
            "sicine",
            "siculis",
            "sicut",
            "signiferumque",
            "significet",
            "silano",
            "similia",
            "similique",
            "simplicem",
            "simul",
            "simulent",
            "sin",
            "sinat",
            "sine",
            "singulis",
            "singulos",
            "sinit",
            "sint",
            "sis",
            "sit",
            "sitisque",
            "sitne",
            "situm",
            "sive",
            "sol",
            "sola",
            "solam",
            "sole",
            "soleat",
            "solemus",
            "solent",
            "solet",
            "solida",
            "soliditatem",
            "solido",
            "solis",
            "solitudo",
            "sollicitant",
            "sollicitare",
            "sollicitudines",
            "solum",
            "soluta",
            "solvantur",
            "sophocles",
            "spatio",
            "spe",
            "specie",
            "spernat",
            "splendide",
            "splendido",
            "splendore",
            "sponte",
            "stabilem",
            "stabilique",
            "stabilitas",
            "stare",
            "statim",
            "statu",
            "statua",
            "statuam",
            "statuat",
            "statue",
            "statuerunt",
            "status",
            "stoici",
            "stoicis",
            "stoicos",
            "studia",
            "studiis",
            "studio",
            "studiose",
            "studium",
            "studuisse",
            "stulti",
            "stultorum",
            "stultus",
            "sua",
            "suam",
            "suapte",
            "suas",
            "suavitate",
            "suaviter",
            "sublata",
            "sublatum",
            "subtilius",
            "successerit",
            "successionem",
            "succumbere",
            "suis",
            "sum",
            "sumitur",
            "summa",
            "summam",
            "summis",
            "summo",
            "summum",
            "summumque",
            "sumus",
            "sunt",
            "suo",
            "superstitio",
            "superstitione",
            "suppetet",
            "supplicii",
            "susceperant",
            "suscepi",
            "suscipere",
            "susciperet",
            "suscipiantur",
            "suscipiet",
            "suscipit",
            "suspicio",
            "suspicor",
            "sustulisti",
            "suum",
            "synephebos",
            "t",
            "tale",
            "talem",
            "tali",
            "tam",
            "tamen",
            "tamquam",
            "tamque",
            "tandem",
            "tanta",
            "tantalo",
            "tantam",
            "tantas",
            "tantis",
            "tantopere",
            "tantum",
            "tarentinis",
            "te",
            "telos",
            "temeritas",
            "temeritate",
            "temperantia",
            "temperantiam",
            "temperantiamque",
            "tempora",
            "tempore",
            "temporibus",
            "temporis",
            "tempus",
            "teneam",
            "tenebimus",
            "tenebo",
            "tenent",
            "tenere",
            "tenetur",
            "tenuit",
            "terentianus",
            "terentii",
            "terminari",
            "terminatas",
            "terrore",
            "terroribus",
            "tertio",
            "tertium",
            "testibus",
            "texit",
            "theatro",
            "theophrasti",
            "theophrastus",
            "theseo",
            "tibi",
            "tibique",
            "timeam",
            "timentis",
            "timeret",
            "timidiores",
            "timiditatem",
            "timorem",
            "tite",
            "titillaret",
            "tolerabiles",
            "tollatur",
            "tollit",
            "tollitur",
            "tollunt",
            "torquate",
            "torquatis",
            "torquato",
            "torquatos",
            "torquatum",
            "torquatus",
            "torqueantur",
            "torquem",
            "torquentur",
            "tot",
            "tota",
            "totam",
            "totum",
            "totus",
            "tractat",
            "tractatas",
            "tractatos",
            "tractavissent",
            "tradere",
            "tradidisse",
            "tradit",
            "traditur",
            "tradunt",
            "tranquillae",
            "tranquillat",
            "tranquilli",
            "tranquillitate",
            "tranquillitatem",
            "transferam",
            "transferre",
            "transferrem",
            "tria",
            "triari",
            "triario",
            "triarium",
            "triarius",
            "tribuat",
            "tribus",
            "tritani",
            "tu",
            "tua",
            "tuemur",
            "tuentur",
            "tueri",
            "tum",
            "tuo",
            "turbent",
            "turbulenta",
            "turbulentaeque",
            "turma",
            "turpe",
            "turpis",
            "turpius",
            "tutiorem",
            "tuum",
            "uberiora",
            "uberius",
            "ubi",
            "ulla",
            "ullam",
            "ullius",
            "ullo",
            "ullum",
            "ullus",
            "ultima",
            "ultimum",
            "umbram",
            "umquam",
            "una",
            "unam",
            "unde",
            "universas",
            "unum",
            "urbane",
            "urbanitas",
            "urbes",
            "usque",
            "usu",
            "usus",
            "ut",
            "utamur",
            "utens",
            "uterque",
            "uti",
            "utilior",
            "utilitas",
            "utilitate",
            "utilitatibus",
            "utinam",
            "utramque",
            "utraque",
            "utrisque",
            "utriusque",
            "utroque",
            "utrum",
            "utrumque",
            "utrumvis",
            "utuntur",
            "vacare",
            "vacillare",
            "vacuitate",
            "valetudinis",
            "variari",
            "varias",
            "variis",
            "vel",
            "velim",
            "velint",
            "velit",
            "vellem",
            "venandi",
            "vendibiliora",
            "veniam",
            "veniamus",
            "veniat",
            "venire",
            "venisset",
            "venustate",
            "vera",
            "verbi",
            "verbis",
            "verborum",
            "verbum",
            "verear",
            "verentur",
            "veri",
            "verissimum",
            "veritatis",
            "veritus",
            "veriusque",
            "vero",
            "versatur",
            "versuum",
            "verterem",
            "verterunt",
            "verum",
            "veserim",
            "vester",
            "vestra",
            "vestrae",
            "veterum",
            "vetuit",
            "vexetur",
            "vi",
            "via",
            "viam",
            "vias",
            "vicinum",
            "victi",
            "vide",
            "videamus",
            "videantur",
            "videatur",
            "videbitur",
            "videmus",
            "videntur",
            "video",
            "videor",
            "videre",
            "viderer",
            "videretur",
            "videri",
            "videro",
            "videtis",
            "videtisne",
            "videtur",
            "vidisse",
            "vidit",
            "vigiliae",
            "vim",
            "vindicet",
            "viris",
            "viros",
            "virtus",
            "virtute",
            "virtutem",
            "virtutes",
            "virtutibus",
            "virtutum",
            "vis",
            "vita",
            "vitae",
            "vitam",
            "vitiis",
            "vitium",
            "vituperandae",
            "vituperari",
            "vituperata",
            "vituperatoribus",
            "vituperatum",
            "vivamus",
            "vivatur",
            "vivendi",
            "vivendo",
            "vivendum",
            "vivere",
            "viveremus",
            "vivi",
            "vix",
            "vocant",
            "voce",
            "vocent",
            "vocet",
            "voluerint",
            "voluit",
            "volumus",
            "volunt",
            "voluntates",
            "voluptaria",
            "voluptas",
            "voluptate",
            "voluptatem",
            "voluptates",
            "voluptati",
            "voluptatibus",
            "voluptatis",
            "voluptatum",
            "vos",
            "vulgo",
            "vult",
            "zenonem",
        )

}
